#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-KjEJYPYZO4SBblo4w3yP8J
key:                  http-conduit-2.3.9.1-KjEJYPYZO4SBblo4w3yP8J
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  a45b368edd13fc7fc469f473f4bb61cc
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-KjEJYPYZO4SBblo4w3yP8J
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    attoparsec-0.14.4-8Ihrc92tki9CPtxJ7iMWhq
    attoparsec-aeson-2.2.0.0-Ddk7Uy4UfJ8OMDmSCgS6v base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-8P16HBmakUKG1It6ArZYEY
    conduit-extra-1.3.8-LOPp6e09V66LxLJXrnknNu
    http-client-0.7.19-A1qGvj2MlivKXlcAABR34l
    http-client-tls-0.3.6.4-63NdgoH5NGbC0F7SbjBwuZ
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ mtl-2.3.1
    resourcet-1.2.6-G3oEY3e1QnrAdomD3ZD7m7 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

